# Bitbucket Integration

> This guide walks you through the process of installing OpenHands Cloud for your Bitbucket repositories. Once set up, it will allow OpenHands to work with your Bitbucket repository.

## Prerequisites

* Signed in to [OpenHands Cloud](https://app.all-hands.dev) with [a Bitbucket account](/openhands/usage/cloud/openhands-cloud).

## Adding Bitbucket Repository Access

Upon signing into OpenHands Cloud with a Bitbucket account, OpenHands will have access to your repositories.

## Working With Bitbucket Repos in Openhands Cloud

After signing in with a Bitbucket account, use the `Open Repository` section to select the appropriate repository and
branch you'd like OpenHands to work on. Then click on `Launch` to start the conversation!

<img src="https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=e6b11dcf83062ccee3a22d107440c976" alt="Connect Repo" data-og-width="344" width="344" data-og-height="269" height="269" data-path="openhands/static/img/connect-repo.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=280&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=0cc85cb018c8f777b12e61a6dc5ae19c 280w, https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=560&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=f17fb0d0921687f84ecf70af8397f66e 560w, https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=840&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=48daba417c153e0de6bde29dd624fad7 840w, https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=1100&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=232731f674c4b56709577803909357de 1100w, https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=1650&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=8040c688490febdd6c9d7df0b7bc0fcf 1650w, https://mintcdn.com/allhandsai/iROoLZU8-F_m1dYO/openhands/static/img/connect-repo.png?w=2500&fit=max&auto=format&n=iROoLZU8-F_m1dYO&q=85&s=3810134f59fa44661ff3e6bc4772cff0 2500w" />

## IP Whitelisting

If your Bitbucket Cloud instance has IP restrictions, you'll need to whitelist the following IP addresses to allow
OpenHands to access your repositories:

### Core App IP

```
34.68.58.200
```

### Runtime IPs

```
34.10.175.217
34.136.162.246
34.45.0.142
34.28.69.126
35.224.240.213
34.70.174.52
34.42.4.87
35.222.133.153
34.29.175.97
34.60.55.59
```

## Next Steps

* [Learn about the Cloud UI](/openhands/usage/cloud/cloud-ui).
* [Use the Cloud API](/openhands/usage/cloud/cloud-api) to programmatically interact with OpenHands.


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt